# Generated by Django 3.2.3 on 2021-08-30 10:07

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0062_comment_models_and_pagesubscription'),
        ('cjk404', '0003_pagenotfoundentry_regular_expression'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pagenotfoundentry',
            name='hits',
            field=models.PositiveIntegerField(default=1, verbose_name='Number of Hits (Page Views)'),
        ),
        migrations.AlterField(
            model_name='pagenotfoundentry',
            name='last_hit',
            field=models.DateTimeField(verbose_name='Last Hit (Last Page View)'),
        ),
        migrations.AlterField(
            model_name='pagenotfoundentry',
            name='redirect_to_page',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.page', verbose_name='Redirect To (Wagtail Page)'),
        ),
        migrations.AlterField(
            model_name='pagenotfoundentry',
            name='redirect_to_url',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='New Path / Redirect To (URL)'),
        ),
        migrations.AlterField(
            model_name='pagenotfoundentry',
            name='regular_expression',
            field=models.BooleanField(default=False, verbose_name='Regular Expression'),
        ),
        migrations.AlterField(
            model_name='pagenotfoundentry',
            name='site',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='pagenotfound_entries', to='wagtailcore.site', verbose_name='Website / Domain'),
        ),
        migrations.AlterField(
            model_name='pagenotfoundentry',
            name='url',
            field=models.CharField(max_length=200, verbose_name='Old Path / Redirect From (URL)'),
        ),
    ]
