# Generated by Django 3.2.7 on 2021-10-11 20:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cjk404', '0005_auto_20211011_2131'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pagenotfoundentry',
            name='created',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Created'),
        ),
        migrations.AlterField(
            model_name='pagenotfoundentry',
            name='hits',
            field=models.PositiveIntegerField(default=0, verbose_name='# Hits'),
        ),
        migrations.AlterField(
            model_name='pagenotfoundentry',
            name='last_hit',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Last Hit'),
        ),
    ]
