# Generated by Django 3.2.7 on 2021-10-11 19:31

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0062_comment_models_and_pagesubscription'),
        ('cjk404', '0004_auto_20210830_1007'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pagenotfoundentry',
            name='hits',
            field=models.PositiveIntegerField(default=1, verbose_name='# Hits'),
        ),
        migrations.AlterField(
            model_name='pagenotfoundentry',
            name='last_hit',
            field=models.DateTimeField(verbose_name='Last Hit'),
        ),
        migrations.AlterField(
            model_name='pagenotfoundentry',
            name='redirect_to_page',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.page', verbose_name='Redirect to Page'),
        ),
        migrations.AlterField(
            model_name='pagenotfoundentry',
            name='redirect_to_url',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Redirect to URL'),
        ),
        migrations.AlterField(
            model_name='pagenotfoundentry',
            name='regular_expression',
            field=models.BooleanField(default=False, verbose_name='RegExp'),
        ),
        migrations.AlterField(
            model_name='pagenotfoundentry',
            name='site',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='pagenotfound_entries', to='wagtailcore.site', verbose_name='Site'),
        ),
        migrations.AlterField(
            model_name='pagenotfoundentry',
            name='url',
            field=models.CharField(max_length=200, verbose_name='Redirect from URL'),
        ),
    ]
