# Generated by Django 3.2.5 on 2021-08-10 14:21

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailcore', '0062_comment_models_and_pagesubscription'),
    ]

    operations = [
        migrations.CreateModel(
            name='PageNotFoundEntry',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('url', models.CharField(max_length=200)),
                ('redirect_to_url', models.CharField(blank=True, max_length=200, null=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('last_hit', models.DateTimeField()),
                ('hits', models.PositiveIntegerField(default=1)),
                ('permanent', models.BooleanField(default=False)),
                ('redirect_to_page', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.page')),
                ('site', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='pagenotfound_entries', to='wagtailcore.site')),
            ],
            options={
                'verbose_name_plural': 'page not found redirects',
                'ordering': ('-hits',),
            },
        ),
    ]
