# Generated by Django 4.0.7 on 2022-08-10 20:25

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    replaces = [('cjk404', '0001_initial'), ('cjk404', '0002_alter_pagenotfoundentry_id'), ('cjk404', '0003_pagenotfoundentry_regular_expression'), ('cjk404', '0004_auto_20210830_1007'), ('cjk404', '0005_auto_20211011_2131'), ('cjk404', '0006_auto_20211011_2219')]

    initial = True

    dependencies = [
        ('wagtailcore', '0062_comment_models_and_pagesubscription'),
    ]

    operations = [
        migrations.CreateModel(
            name='PageNotFoundEntry',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('url', models.CharField(max_length=200, verbose_name='Redirect from URL')),
                ('redirect_to_url', models.CharField(blank=True, max_length=200, null=True, verbose_name='Redirect to URL')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('last_hit', models.DateTimeField(auto_now_add=True, verbose_name='Last Hit')),
                ('hits', models.PositiveIntegerField(default=0, verbose_name='# Hits')),
                ('permanent', models.BooleanField(default=False)),
                ('redirect_to_page', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.page', verbose_name='Redirect to Page')),
                ('site', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='pagenotfound_entries', to='wagtailcore.site', verbose_name='Site')),
                ('regular_expression', models.BooleanField(default=False, verbose_name='RegExp')),
            ],
            options={
                'verbose_name_plural': 'page not found redirects',
                'ordering': ('-hits',),
            },
        ),
    ]
