# Generated by Django 3.2.3 on 2021-08-30 09:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cjk404', '0002_alter_pagenotfoundentry_id'),
    ]

    operations = [
        migrations.AddField(
            model_name='pagenotfoundentry',
            name='regular_expression',
            field=models.BooleanField(default=False),
        ),
    ]
